@@ -217,7 +217,7 @@
         <location filename="mainwindow.ui" line="606"/>
         <location filename="ui_mainwindow.h" line="482"/>
         <source>Display help </source>
-        <translation>Exibir a ajuda</translation>
+        <translation>Mostrar ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="609"/>
@@ -265,7 +265,7 @@
     <message>
         <location filename="mainwindow.cpp" line="120"/>
         <source>Running apt-get update... </source>
-        <translation>O apt-get update está em execução...</translation>
+        <translation>A executar &apos;apt-get update&apos;...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="298"/>
